pub struct TypedChatRequest<M: ChatModel, S: Sealed = MissingInput> { /* private fields */ }Expand description
A capability-checked chat request.
M determines which model-specific methods exist, while S prevents sending a request before
it contains user or tool input. Convert with TypedChatRequest::into_raw when a raw extension
field is required.
Implementations
Sourceimpl<M: ChatModel> TypedChatRequest<M, MissingInput>
impl<M: ChatModel> TypedChatRequest<M, MissingInput>
Sourceimpl<M: ChatModel, S: Sealed> TypedChatRequest<M, S>
impl<M: ChatModel, S: Sealed> TypedChatRequest<M, S>
pub const fn model_id(&self) -> &'static str
pub const fn capabilities(&self) -> ModelCapabilities
pub fn system(self, value: impl Into<String>) -> Self
pub fn assistant(self, value: impl Into<String>) -> Self
pub fn temperature(self, value: f32) -> Self
pub fn top_p(self, value: f32) -> Self
pub fn max_tokens(self, value: u32) -> Self
pub fn request_id(self, value: impl Into<String>) -> Self
pub fn user_id(self, value: impl Into<String>) -> Self
pub fn into_raw(self) -> ChatCompletionRequest
Sourceimpl<M: TextChatModel, S: Sealed> TypedChatRequest<M, S>
impl<M: TextChatModel, S: Sealed> TypedChatRequest<M, S>
Sourceimpl<M: VisionChatModel, S: Sealed> TypedChatRequest<M, S>
impl<M: VisionChatModel, S: Sealed> TypedChatRequest<M, S>
pub fn user_parts( self, parts: impl IntoIterator<Item = ContentPart>, ) -> TypedChatRequest<M, Ready>
Sourceimpl<M: SupportsThinking, S: Sealed> TypedChatRequest<M, S>
impl<M: SupportsThinking, S: Sealed> TypedChatRequest<M, S>
Sourceimpl<M: SupportsReasoningEffort, S: Sealed> TypedChatRequest<M, S>
impl<M: SupportsReasoningEffort, S: Sealed> TypedChatRequest<M, S>
Sourcepub fn reasoning_effort(self, value: ReasoningEffort) -> Self
pub fn reasoning_effort(self, value: ReasoningEffort) -> Self
Sets GLM-5.2 reasoning effort.
This method does not exist for models that do not declare the capability:
ⓘ
use rustglm::{Glm51, ReasoningEffort, TypedChatRequest};
let _ = TypedChatRequest::<Glm51>::new()
.reasoning_effort(ReasoningEffort::High);Sourceimpl<M: SupportsTools, S: Sealed> TypedChatRequest<M, S>
impl<M: SupportsTools, S: Sealed> TypedChatRequest<M, S>
pub fn tool(self, value: Tool) -> Self
pub fn tools(self, values: impl IntoIterator<Item = Tool>) -> Self
pub fn tool_result( self, call_id: impl Into<String>, output: impl Into<String>, ) -> TypedChatRequest<M, Ready>
Sourceimpl<M: SupportsToolStream, S: Sealed> TypedChatRequest<M, S>
impl<M: SupportsToolStream, S: Sealed> TypedChatRequest<M, S>
Sourcepub fn tool_stream(self) -> Self
pub fn tool_stream(self) -> Self
Enables incremental Function Call output for models that support tool_stream.
ⓘ
use rustglm::{Glm45Air, TypedChatRequest};
let _ = TypedChatRequest::<Glm45Air>::new().tool_stream();Sourceimpl<M: ChatModel> TypedChatRequest<M, Ready>
impl<M: ChatModel> TypedChatRequest<M, Ready>
pub fn as_raw(&self) -> &ChatCompletionRequest